from easyi2l import EasyI2L, DBType


def main():
    db = EasyI2L.download(DBType.DB1LITEBIN).load()

    # Retrieve all data for IP
    print(db.get_all("1.1.1.1"))


if __name__ == "__main__":
    main()



import enum
import os
import shutil
import zipfile
import time
from pathlib import Path

import IP2Location
import requests
from dotenv import load_dotenv
from tqdm import tqdm

from easyi2l.db_type import DBType
from easyi2l.easyi2l import EasyI2L


def main():
    db = EasyI2L.download(DBType.DB11LITEBIN).load()

    # tests
    print(db.get_all("1.1.1.1"))


if __name__ == "__main__":
    main()



from enum import Enum


class DBType(Enum):
    pass


for i in [1, 3, 5, 9, 11]:
    for variant in ["BIN", "CSV"]:
        for ip in ["", "IPV6"]:
            setattr(
                DBType, f"DB{i}LITE{variant}{ip}",
                {
                    "code": f"DB{i}LITE{variant}{ip}",
                    "file": f"IP2LOCATION-LITE-DB{i}{ip}.{variant}"
                }
            )


import shutil
import time
import zipfile
from pathlib import Path

import requests

from easyi2l.config import db_folder, IP2LOCATION_URL, IP2LOCATION_TOKEN
from easyi2l.db import EasyI2LDB
from easyi2l.db_type import DBType
from easyi2l.logger import logging


class EasyI2L:
    @staticmethod
    def download(database_code: DBType) -> EasyI2LDB:
        # If the file already exists and is a file and is not older than 30 days, return the file
        if (
                (db_folder / database_code["file"]).exists() and
                (db_folder / database_code["file"]).is_file() and
                (db_folder / f"{database_code['file']}.timestamp").exists() and
                (db_folder / f"{database_code['file']}.timestamp").is_file() and
                (time.time() - float(
                    (db_folder / f"{database_code['file']}.timestamp").read_text()) < 30 * 24 * 60 * 60)
        ):
            logging.info(f"Using existing {database_code['file']}")
            return EasyI2LDB(database_code["file"])
        else:
            if (db_folder / database_code["file"]).exists():
                (db_folder / database_code["file"]).unlink()
            if (db_folder / f"{database_code['file']}.timestamp").exists():
                (db_folder / f"{database_code['file']}.timestamp").unlink()

        if not IP2LOCATION_TOKEN:
            logging.error("Please provide IP2LOCATION_TOKEN environment variable")
            raise ValueError("Please provide IP2LOCATION_TOKEN environment variable")

        url = IP2LOCATION_URL.format(TOKEN=IP2LOCATION_TOKEN, DATABASE_CODE=database_code["code"])
        response = requests.get(url, stream=True)

        # Check if the response is a zip file
        if response.headers.get('Content-Type') != 'application/zip':
            raise ValueError(
                f"Expected a zip file, but got {response.headers.get('Content-Type')}\n\tUrl: {url}\n\tCode: {response.status_code}\n\tContent: {response.content}")

        if response.status_code == 200:
            total_size = int(response.headers.get('content-length', 0))
            chunk_size = 1024
            downloaded_size = 0
            with open(f"{database_code['code']}.zip", "wb") as file:
                for data in response.iter_content(chunk_size=chunk_size):
                    file.write(data)
                    downloaded_size += len(data)
                    logging.info(f"Downloading {database_code['code']}.zip: {downloaded_size / total_size:.2%}")

            logging.info(f"Downloaded {database_code['code']}.zip")

            with zipfile.ZipFile(f"{database_code['code']}.zip", "r") as zip_ref:
                for file_info in zip_ref.infolist():
                    if file_info.filename.endswith(('.BIN', '.CSV')):
                        zip_ref.extract(file_info, ".")
                        logging.info(f"Extracted {file_info.filename}")

                        extracted_file = Path(file_info.filename)
                        shutil.move(str(extracted_file), str(db_folder / extracted_file.name))
                        logging.info(f"Moved {extracted_file.name} to {db_folder}")

                        # Create timestamp file
                        Path(db_folder / f"{extracted_file.name}.timestamp").write_text(str(time.time()))

            logging.info(f"Downloaded and extracted {database_code['code']}.zip")
            Path(f"{database_code['code']}.zip").unlink()

        else:
            raise ValueError(
                f"Failed to download {database_code['code']}.zip\n\tUrl: {url}\n\tCode: {response.status_code}")

        return EasyI2LDB(database_code['file'])



import IP2Location

from easyi2l.config import db_folder


class EasyI2LDB:
    def __init__(self, database_code):
        self.database_code = database_code
        self.database_file = None

    def load(self) -> IP2Location.IP2Location:
        return IP2Location.IP2Location(f"{db_folder}/{self.database_code}")


import os
from pathlib import Path

from dotenv import load_dotenv

from easyi2l.logger import logging

IP2LOCATION_URL = "https://www.ip2location.com/download/?token={TOKEN}&file={DATABASE_CODE}"

# load .env
load_dotenv()

IP2LOCATION_TOKEN = os.getenv("IP2LOCATION_TOKEN")
if not IP2LOCATION_TOKEN:
    logging.warning("Please provide IP2LOCATION_TOKEN environment variable")

db_folder = Path(__file__).parent / "IP2LOCATION"
db_folder.mkdir(parents=True, exist_ok=True)
